summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorUlrich Müller <ulm@gentoo.org>2017-02-27 22:49:03 +0100
committerUlrich Müller <ulm@gentoo.org>2017-02-27 22:49:03 +0100
commit0f5206c7ecb03ce261c57de3d600fdb025adabc8 (patch)
tree1c89bde386ae008b532a782bf92ccad8b0998698
parentVersion 1.32 released. (diff)
downloadebuild-mode-0f5206c7ecb03ce261c57de3d600fdb025adabc8.tar.gz
ebuild-mode-0f5206c7ecb03ce261c57de3d600fdb025adabc8.tar.bz2
ebuild-mode-0f5206c7ecb03ce261c57de3d600fdb025adabc8.zip
Update documentation to be less Portage specific.
* ebuild-mode.el: * ebuild-mode.texi: Update documentation to use generic terms where possible, instead of being Portage specific.
-rw-r--r--ChangeLog6
-rw-r--r--ebuild-mode.el10
-rw-r--r--ebuild-mode.texi2
3 files changed, 12 insertions, 6 deletions
diff --git a/ChangeLog b/ChangeLog
index 2f327d2..fe1ced8 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,9 @@
+2017-02-27 Ulrich Müller <ulm@gentoo.org>
+
+ * ebuild-mode.el:
+ * ebuild-mode.texi: Update documentation to use generic terms
+ where possible, instead of being Portage specific.
+
2017-02-26 Ulrich Müller <ulm@gentoo.org>
* Version 1.32 released.
diff --git a/ebuild-mode.texi b/ebuild-mode.texi
index 349a64b..1b616b2 100644
--- a/ebuild-mode.texi
+++ b/ebuild-mode.texi
@@ -74,7 +74,7 @@ As the ebuild format is based on the Bash syntax, sh-mode is called as
a base, where ebuild specific things are added/changed on top.
If font-locking is enabled, keywords are highlighted, both the standard
-set available from vanilla Portage and special functions from all common
+set defined by the package manager and special functions from all common
eclasses. Missing highlighting should be reported on
@code{https://bugs.gentoo.org/}.
diff --git a/ebuild-mode.el b/ebuild-mode.el
index e32b3d0..3f3e0fe 100644
--- a/ebuild-mode.el
+++ b/ebuild-mode.el
@@ -73,7 +73,7 @@ A formfeed is not considered whitespace by this function."
(defvar ebuild-mode-portdir
"/usr/portage"
- "Location of the Portage tree.")
+ "Location of the ebuild repository.")
(defvar ebuild-mode-arch-list
(or
@@ -85,7 +85,7 @@ A formfeed is not considered whitespace by this function."
(replace-match ""))
(sort (split-string (buffer-string)) 'ebuild-mode-arch-lessp))
(file-error nil))
;; could not read architectures from Portage tree, so fall back to default
'("alpha" "amd64" "arm" "hppa" "ia64" "m68k" "mips" "ppc" "ppc64"
"s390" "sh" "sparc" "x86" "amd64-fbsd" "sparc-fbsd" "x86-fbsd"))
"List of architectures.")
@@ -117,7 +117,7 @@ A formfeed is not considered whitespace by this function."
(directory-files (concat ebuild-mode-portdir "/licenses")
nil "\\`[^.]")
(file-error nil))
- "List of licenses, determined from the Portage tree.")
+ "List of licenses, determined from the ebuild repository.")
(defvar ebuild-mode-eclasses
(condition-case nil
@@ -126,7 +126,7 @@ A formfeed is not considered whitespace by this function."
(directory-files (concat ebuild-mode-portdir "/eclass")
nil "\\.eclass\\'"))
(file-error nil))
- "List of eclasses, determined from the Portage tree.")
+ "List of eclasses, determined from the ebuild repository.")
(defvar ebuild-mode-restrict-list
'("binchecks" "bindist" "fetch" "installsources" "mirror"
@@ -228,7 +228,7 @@ Optional argument LIMIT restarts collection after that number of elements."
;;;###autoload
(define-derived-mode ebuild-mode shell-script-mode "Ebuild"
- "Major mode for Portage .ebuild and .eclass files."
+ "Major mode for Gentoo .ebuild and .eclass files."
(if (featurep 'xemacs)
;; make-local-hook gives a byte-compiler warning in GNU Emacs
(make-local-hook 'write-contents-hooks))
@@ -85,7 +85,7 @@ A formfeed is not considered whitespace by this function."
(sort (split-string (buffer-string)) 'ebuild-mode-arch-lessp))
(file-error nil))
- ;; could not read architectures from Portage tree, so fall back to default
+ ;; could not read architectures from repository, so fall back to default
'("alpha" "amd64" "arm" "hppa" "ia64" "m68k" "mips" "ppc" "ppc64"
"s390" "sh" "sparc" "x86" "amd64-fbsd" "sparc-fbsd" "x86-fbsd"))